/**
 * @package css-modules-types-loader
 * @license MIT
 * @version 0.5.12
 * @author nuintun <nuintun@qq.com>
 * @description A webpack loader that dynamically generates TypeScript typings for CSS modules from css-loader.
 * @see https://github.com/nuintun/css-modules-types-loader#readme
 */

'use strict';

const schema = require('./schema.cjs');
const index = require('./generate/index.cjs');

/**
 * @module index
 */
const loader = function loader(content, sourceMap, additionalData) {
  const callback = this.async();
  const logger = this.getLogger('css-modules-types-loader');
  const path = `${this.resourcePath}.d.ts`;
  const { eol, banner } = this.getOptions(schema.schema);
  callback(null, content, sourceMap, additionalData);
  index.generate({ eol, path, banner, content }).catch(error => {
    logger.error(error.message);
  });
};

module.exports = loader;
